==> abqpy-2018.5.2-py3-none-any.whl: abaqus/Mesh/MeshFaceArray.py <==
from __future__ import annotations

from typing import List, Sequence, Union

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .MeshFace import MeshFace


@abaqus_class_doc
class MeshFaceArray(List[MeshFace]):
    """The MeshFaceArray is a sequence of MeshFace objects.

    .. note::
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].elementFaces
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].elementFaces
            mdb.models[name].rootAssembly.instances[name].elementFaces
    """

    @abaqus_method_doc
    def __init__(self, faces: List[MeshFace]):
        """This method creates a MeshFaceArray object.

        .. note::
            This function can be accessed by::

                mesh.MeshFaceArray

        Parameters
        ----------
        faces
            A list of MeshFace objects.

        Returns
        -------
        MeshFaceArray
            A MeshFaceArray object.
        """
        super().__init__()

    @abaqus_method_doc
    def getSequenceFromMask(self, mask: Union[str, Sequence[str]]) -> MeshFaceArray:
        """This method returns the objects in the MeshFaceArray identified using the specified
        **mask**. When large number of objects are involved, this method is highly efficient.

        Parameters
        ----------
        mask
            A String specifying the object or objects.

        Returns
        -------
        MeshFaceArray
            A MeshFaceArray object.

        Raises
        ------
        Error
            The mask results in an empty sequence, An exception occurs if the resulting sequence is empty.
        """
        ...

    @abaqus_method_doc
    def getMask(self):
        """This method returns a string specifying the object or objects.

        Returns
        -------
        str
            A String specifying the object or objects.
        """
        ...

==> abqpy-2021.1.1-py3-none-any.whl: abaqus/Mesh/MeshFaceArray.py <==
import typing

from .MeshFace import MeshFace


class MeshFaceArray(typing.List[MeshFace]):
    """The MeshFaceArray is a sequence of MeshFace objects.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import part
            mdb.models[name].parts[name].elementFaces
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].elementFaces
            mdb.models[name].rootAssembly.instances[name].elementFaces
    """

    def __init__(self, faces: typing.List[MeshFace]):
        """This method creates a MeshFaceArray object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mesh.MeshFaceArray

        Parameters
        ----------
        faces
            A list of MeshFace objects.

        Returns
        -------
        MeshFaceArray
            A :py:class:`~abaqus.Mesh.MeshFaceArray.MeshFaceArray` object.
        """
        super().__init__()

    def getSequenceFromMask(self, mask: str):
        """This method returns the objects in the MeshFaceArray identified using the specified
        **mask**. When large number of objects are involved, this method is highly efficient.

        Parameters
        ----------
        mask
            A String specifying the object or objects.

        Returns
        -------
        MeshFaceArray
            A :py:class:`~abaqus.Mesh.MeshFaceArray.MeshFaceArray` object.

        Raises
        ------
        Error: The mask results in an empty sequence            
            An exception occurs if the resulting sequence is empty.
        """
        ...

    def getMask(self):
        """This method returns a string specifying the object or objects.

        Returns
        -------
        str
            A String specifying the object or objects.
        """
        ...
